@@ -1,9 +1,9 @@
 from PyFlow.Core.Common import *
 from PyFlow.Core.NodeBase import NodePinsSuggestionsHelper
-from common import DeviceNode, get_property_value, get_enum_values
+from common import get_property_value, get_enum_values, CameraNode
 
 
-class MonoCameraNode(DeviceNode):
+class MonoCameraNode(CameraNode):
     def __init__(self, name):
         import depthai
         super(MonoCameraNode, self).__init__(name)
@@ -31,12 +31,21 @@ class MonoCameraNode(DeviceNode):
     def description():
         return "Description in rst format."
 
+    def getId(self):
+        nodes = self.getWrapper().canvasRef().graphManager.findRootGraph().getNodesList()
+        cams = list(sorted(map(lambda node: node.name, filter(lambda node: isinstance(node, MonoCameraNode), nodes))))
+        cam_idx = cams.index(self.name)
+        if cam_idx == 0:
+            return 1
+        else:
+            return 2
+
     def build_pipeline(self, pipeline):
         import depthai
         cam = pipeline.createMonoCamera()
-        cam.setResolution(depthai.MonoCameraProperties.SensorResolution.THE_720_P)
         cam.setResolution(getattr(
             depthai.MonoCameraProperties.SensorResolution,
             get_property_value(self, "resolution", "THE_720_P")
         ))
+        cam.setCamId(self.getId())
         self.connection_map["out"] = cam.out
