@@ -1,9 +1,6 @@
-import cv2
-
-from common import HostNode, PreviewNode
 from PyFlow.Core.Common import *
 from PyFlow.Core.NodeBase import NodePinsSuggestionsHelper
-from config import DEBUG
+from common import PreviewNode, HostNode
 
 
 class FramePreviewNode(HostNode, PreviewNode):
@@ -34,8 +31,7 @@ class FramePreviewNode(HostNode, PreviewNode):
         return "Description in rst format."
 
     def run(self, *args, **kwargs):
-        if DEBUG:
-            print(f"{self.name} waiting...")
-        self.display_frame = self.receive("frame")
-        if DEBUG:
-            print(f"{self.name} updated.")
+        while self._running:
+            in_data = self.queue.get()
+            if in_data is not None:
+                self.display_frame = in_data['data']
